Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(292)

Unified Diff: device/time_zone_monitor/android/java/src/org/chromium/device/time_zone_monitor/TimeZoneMonitor.java

Issue 2353283002: [TimeZoneMonitor] Decouple //content/browser/time_zone_monitor* to //device/. (Closed)
Patch Set: Do not set output_name in gn Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « device/time_zone_monitor/DEPS ('k') | device/time_zone_monitor/android/time_zone_monitor_jni_registrar.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/time_zone_monitor/android/java/src/org/chromium/device/time_zone_monitor/TimeZoneMonitor.java
diff --git a/content/public/android/java/src/org/chromium/content/browser/TimeZoneMonitor.java b/device/time_zone_monitor/android/java/src/org/chromium/device/time_zone_monitor/TimeZoneMonitor.java
similarity index 80%
rename from content/public/android/java/src/org/chromium/content/browser/TimeZoneMonitor.java
rename to device/time_zone_monitor/android/java/src/org/chromium/device/time_zone_monitor/TimeZoneMonitor.java
index ff1726463136459304c51b32ac61fd505242a8a4..21c21237df111fcd85545c8f8e913a4946f2d873 100644
--- a/content/public/android/java/src/org/chromium/content/browser/TimeZoneMonitor.java
+++ b/device/time_zone_monitor/android/java/src/org/chromium/device/time_zone_monitor/TimeZoneMonitor.java
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-package org.chromium.content.browser;
+package org.chromium.device.time_zone_monitor;
import android.content.BroadcastReceiver;
import android.content.Context;
@@ -14,11 +14,11 @@ import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
/**
* Android implementation details for content::TimeZoneMonitorAndroid.
*/
-@JNINamespace("content")
+@JNINamespace("device")
class TimeZoneMonitor {
- private static final String TAG = "cr.TimeZoneMonitor";
+ private static final String TAG = "cr_TimeZoneMonitor";
private final Context mAppContext;
private final IntentFilter mFilter = new IntentFilter(Intent.ACTION_TIMEZONE_CHANGED);
@@ -38,7 +38,7 @@ class TimeZoneMonitor {
/**
* Start listening for intents.
* @param nativePtr The native content::TimeZoneMonitorAndroid to notify of time zone changes.
*/
private TimeZoneMonitor(Context context, long nativePtr) {
mAppContext = context.getApplicationContext();
@@ -61,8 +61,8 @@ class TimeZoneMonitor {
}
/**
* Native JNI call to content::TimeZoneMonitorAndroid::TimeZoneChanged.
* See content/browser/time_zone_monitor_android.cc.
*/
private native void nativeTimeZoneChangedFromJava(long nativeTimeZoneMonitorAndroid);
}
@@ -14,11 +14,11 @@ import org.chromium.base.annotations.CalledByNative;
import org.chromium.base.annotations.JNINamespace;
/**
- * Android implementation details for content::TimeZoneMonitorAndroid.
+ * Android implementation details for device::TimeZoneMonitorAndroid.
*/
@@ -38,7 +38,7 @@ class TimeZoneMonitor {
/**
* Start listening for intents.
- * @param nativePtr The native content::TimeZoneMonitorAndroid to notify of time zone changes.
+ * @param nativePtr The native device::TimeZoneMonitorAndroid to notify of time zone changes.
*/
private TimeZoneMonitor(Context context, long nativePtr) {
@@ -61,8 +61,8 @@ class TimeZoneMonitor {
}
/**
- * Native JNI call to content::TimeZoneMonitorAndroid::TimeZoneChanged.
- * See content/browser/time_zone_monitor_android.cc.
+ * Native JNI call to device::TimeZoneMonitorAndroid::TimeZoneChanged.
+ * See device/time_zone_monitor/time_zone_monitor_android.cc.
*/
private native void nativeTimeZoneChangedFromJava(long nativeTimeZoneMonitorAndroid);
« no previous file with comments | « device/time_zone_monitor/DEPS ('k') | device/time_zone_monitor/android/time_zone_monitor_jni_registrar.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698